@@ -14,6 +14,7 @@ import logging
 import re
 from urllib.parse import urlparse
 from prettytable import PrettyTable, ALL
+import pkg_resources  # part of setuptools
 
 
 # yaml 数据模型
@@ -1452,36 +1453,26 @@ def main(argvs=None):
 
     elif command == "clean":
         yhgit().clean()
-    elif command == "version":
-        debugInfo("version 2.4")
+    elif command == "version" or command == "-v":
+        debugInfo(pkg_resources.require("yhgit")[0].version)
     elif command == "help" or command == "-h":
 
-        """
-            文档指令
-            0. install 组件  根据本地PodfileLocal.yaml中的配置，获取新分支branch，然后基于的组件新建分支branch
-            1. install -b branch 组件 根据分支branch，然后基于组件新建分支branch
-            2. status 根据本地PodfileLocal.yaml中配置的仓库，获取所有仓库的开发分支及仓库状态
-            3. commit 根据本地PodfileLocal.yaml中配置的仓库，提交本地仓库中的修改
-            4. pull   根据本地PodfileLocal.yaml中配置的仓库，拉取远端仓库中代码
-            5. merge   根据本地PodfileLocal.yaml中配置的仓库，然后基于组件merge 分支到当前开发分支，并自动提交
-            6. push   根据本地PodfileLocal.yaml中配置的仓库，推送本地代码到远端
-            5. push   根据本地PodfileLocal.yaml中配置的仓库，推送本地代码到远端
-
-        """
-
-        table = PrettyTable(["编号", "指令", "参数", "说明"])
+        table = PrettyTable(["编号", "指令", "参数", "说明", "使用"])
         table.add_row(
-            [0, "install", "-b 指定分支名; 组件 指定 新建分支的组件", "根据分支branch，然后基于组件新建分支branch"])
-        table.add_row([1, "install", "组件 指定 新建分支的组件",
-                       "根据本地PodfileLocal.yaml中的配置，获取新分支branch，然后基于的组件新建分支branch"])
-        table.add_row([2, "status", "", "根据本地PodfileLocal.yaml中配置的仓库，获取所有仓库的开发分支及仓库状态"])
-        table.add_row([3, "commit", "-m 指定提交的信息", "根据本地PodfileLocal.yaml中配置的仓库，提交本地仓库中的修改"])
-        table.add_row([4, "pull", "", "根据本地PodfileLocal.yaml中配置的仓库，拉取远端仓库中代码"])
-        table.add_row([5, "push", "", "根据本地PodfileLocal.yaml中配置的仓库，推送本地代码到远端"])
+            [0, "install", "-b 指定分支名; 组件 指定 新建分支的组件",
+             "根据分支branch，然后基于组件或者PodfileLocal.yaml中的配置，新建分支branch", "yhgit install -b test abc \n yhgit install"])
+        table.add_row([1, "status", "", "根据本地PodfileLocal.yaml中配置的仓库，获取所有仓库的开发分支及仓库状态", "yhgit status"])
+        table.add_row([2, "commit", "-m 指定提交的信息", "根据本地PodfileLocal.yaml中配置的仓库，提交本地仓库中的修改", "yhgit commit -m \'提交信息\'"])
+        table.add_row([3, "pull", "", "根据本地PodfileLocal.yaml中配置的仓库，拉取远端仓库中代码", "yhgit pull"])
+        table.add_row([4, "push", "", "根据本地PodfileLocal.yaml中配置的仓库，推送本地代码到远端", "yhgit push"])
         table.add_row(
-            [5, "merge", "-b 指定分支名; 组件 指定 merge的组件", "然后基于组件merge 分支到当前开发分支，并自动提交"])
-        table.add_row([6, "release", "", "根据本地PodfileModule.yaml中配置的仓库，合并开发分支到master，并自动打新的tag"])
-        table.add_row([7, "clean", "", "清空本地PodfileLocal.yaml 及 modules文件夹"])
+            [5, "merge", "-b 指定分支名; 组件 指定 merge的组件", "然后基于组件merge 分支到当前开发分支，并自动提交", "yhgit merge -b master abc"])
+        table.add_row([6, "release", "组件： 指定组件", "根据本地PodfileModule.yaml中配置的仓库或者手动指定仓库，合并开发分支到master，并自动打新的tag",
+                       "yhgit release abc"])
+        table.add_row([7, "clean", "", "清空本地PodfileLocal.yaml 及 modules文件夹", "yhgit clean"])
+        table.add_row([8, "version", "", "查看版本号", "yhgit version \n yhgit -v"])
+        table.add_row([8, "help", "", "查看帮助文档", "yhgit help \n yhgit -h"])
+
         table.align[1] = '1'
         table.border = True
         table.junction_char = '+'
